

import os, sys, inspect, math
import subprocess


traci_port = 49152
connection_label = "python_connection"
connection_order = 1
SUMO_cfg_file = "\\sumo-files\A9_Nord_5km_medium.sumo.cfg" #relative path to relevant sumo.cfg file 
                                                      #--> saved sim state will be stored under 
                                                      #same name with ending _saved_state.xml
SUMO_sim_state="\sumo-files\A9_Nord_5km_medium_saved_state.xml"

SIM_STEPS=2000

if 'SUMO_HOME' in os.environ:
    tools = os.path.join(os.environ['SUMO_HOME'], 'tools')
    sys.path.append(tools)
else:   
    sys.exit("please declare environment variable 'SUMO_HOME'")

import traci
from sumolib import checkBinary  # noqa

sumoBinary = checkBinary('sumo-gui')

current_path=os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe()))) 
p = subprocess.Popen([sumoBinary, "-c", current_path+SUMO_cfg_file, "--load-state" , current_path+SUMO_sim_state ,"--remote-port" ,str(traci_port) ,"--num-clients" ,"1", "--seed", "22223", "--no-step-log"], stdout = subprocess.PIPE, stderr = subprocess.PIPE)
print "Started SUMO"
traci.init(port=traci_port, label=connection_label) # initialize the traci connection
pyConnection = traci.getConnection(connection_label) # access the connection handle

vehID="South_to_North_Car.19"
KEEPROUTE=0
MetersPerStep = 1
MoveEveryXSteps = 1 # result for 1 is that no usable lane change state is retrieved, for 2 every second step, plausible information is retrieved, etc.


step = 0
while step<SIM_STEPS:
    
    time=traci.simulation.getTime()

    if time%10 == 0:
        print("Traci simulation time [s]" + str(time)) # print time in seconds
        
    if step == 1:
        traci.vehicle.setColor(vehID,[255,255,255])
        traci.gui.trackVehicle('View #0', vehID)

    #calculate new position to move to
    [posX, posY]=traci.vehicle.getPosition(vehID)
    angle=-1*traci.vehicle.getAngle(vehID)+90
    if angle<0:
        angle=angle+360
    angle=math.pi*angle/180
    posXnew= posX+MetersPerStep*math.cos(angle)
    posYnew= posY+MetersPerStep*math.sin(angle)
    
    if step%MoveEveryXSteps==0:
        traci.vehicle.moveToXY(vehID, traci.lane.getEdgeID(traci.vehicle.getLaneID(vehID)), traci.vehicle.getLaneIndex(vehID), posXnew, posYnew, angle=-1073741824.0, keepRoute=KEEPROUTE)
        print "Moved vehicle at step", step
    traci.simulation.step() # perform simulation step, required to be executed by all clients
    
    print "LangeChangeState", traci.vehicle.getLaneChangeState(vehID, -1)

    step += 1

pyConnection.close()
